@@ -64,12 +64,12 @@ def listConfig():
 
 
 
-def getValue(key, deactivate_kv_access=True):
+def getValue(key, deactivate_kv_access=True, label=None):
     response = ""
     appConfigurationConnectionString = os.environ["APPCONFIGURATION_CONNECTION_STRING"]
     app_config_client = AzureAppConfigurationClient.from_connection_string(appConfigurationConnectionString)
     try:
-        retrieved_config_setting = app_config_client.get_configuration_setting(key=str(key))
+        retrieved_config_setting = app_config_client.get_configuration_setting(key=str(key), label=label)
         logging.info("Key: " + retrieved_config_setting.key + ", Value: " + retrieved_config_setting.value)
         config_type = retrieved_config_setting.as_dict()['content_type']
         if (deactivate_kv_access==False) and ("keyvaultref" in config_type):
